Learn R Programming

pkglite (version 0.2.5)

pkglite-package: pkglite: Compact Package Representations

Description

logo

A tool, grammar, and standard to represent and exchange R package source code as text files. Converts one or more source packages to a text file and restores the package structures from the file.

Arguments

Author

Maintainer: Benjamin Wang benjamin.wang@merck.com

Authors:

Other contributors:

  • Amin Shirazi [contributor]

  • Jeff Cheng [contributor]

  • Danfeng Fu [contributor]

  • Merck & Co., Inc., Rahway, NJ, USA and its affiliates [copyright holder]

See Also